Module: MrubyGemScaffolding

Defined in:
lib/mruby_gem_scaffolding.rb,
lib/mruby_gem_scaffolding/version.rb

Defined Under Namespace

Modules: Utility

Constant Summary collapse

VERSION =
"1.1.0"

Class Method Summary collapse

Class Method Details

.empty_projectObject



22
23
24
25
26
27
28
29
30
31
32
33
# File 'lib/mruby_gem_scaffolding.rb', line 22

def empty_project
  {
    "README.md" => '',
    "mrbgem.rake" => '',
    "include" => {},
    "mrblib" => {},
    "src" => {},
    "tools" => {},
    "test" => {},
    "LICENSE" => '',
  }
end

.generate(user_name:, project_name:) ⇒ Object



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/mruby_gem_scaffolding.rb', line 35

def generate(user_name:, project_name:)
  result = empty_project

  result["README.md"] =
    <<MULTILINE
# #{Utility.camel_case(project_name)}
An mruby gem created by #{user_name} using mruby_gem_scaffolding.
MULTILINE

  result["mrbgem.rake"] =
    <<MULTILINE
MRuby::Gem::Specification.new('#{Utility.snake_case(project_name)}') do |spec|
  spec.license = 'MIT'
  spec.author  = '#{user_name}'
end
MULTILINE

  result["src"]["#{Utility.snake_case(project_name)}.c"] =
    <<MULTILINE
#include <mruby.h>
#include <stdio.h>

// defining the function to be later bound to a ruby method
static mrb_value
hello_world(mrb_state *mrb, mrb_value self)
{
printf("Hello World\\n");

return mrb_nil_value(); // return null
}

// gem initializer
void
mrb_#{Utility.snake_case(project_name)}_gem_init(mrb_state* mrb) {
struct RClass *#{Utility.snake_case(project_name)}_class = mrb_define_module(mrb, "#{Utility.camel_case(project_name)}");
mrb_define_class_method(
  mrb,                    // Mruby VM state
  #{Utility.snake_case(project_name)}_class,  // Class we bind method to
  "say_hello",            // Name of method
  hello_world,        // Function we are binding as a method
  MRB_ARGS_NONE()         // How many arguments are optional/required
);
}

// gem finalizer
void
mrb_#{Utility.snake_case(project_name)}_gem_final(mrb_state* mrb) {

}
MULTILINE

  result["mrblib"]["#{Utility.snake_case(project_name)}.rb"] =
    <<MULTILINE
module #{Utility.camel_case(project_name)}
  class << self
def say_goodbye
  puts "Goodbye"
end
  end
end
MULTILINE

  result["LICENSE"] =
    <<MULTILINE
The MIT License (MIT)

Copyright (c) #{Time.now.year} #{user_name}

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

MULTILINE

  return result
end

.write(dir, hash_data) ⇒ Object



126
127
128
129
130
131
132
133
134
135
# File 'lib/mruby_gem_scaffolding.rb', line 126

def write(dir, hash_data)
  Dir.mkdir dir unless File.exists? dir
  hash_data.each do |key, value|
    if value.is_a? Hash
      write("#{dir}/#{key}", value)
    else
      File.open("#{dir}/#{key}", 'w') { |file| file.write(value) }
    end
  end
end